@@ -20,8 +20,9 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
+
 __author__:  str = "Kevin Liu"
 __license__: str = "MIT"
-__version__: str = "0.0.1"
+__version__: str = "0.0.5"
 
-from hashball import hashball
\ No newline at end of file
+from hashball.hashball import HashBall
\ No newline at end of file
